@@ -17,25 +17,28 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.8.1 (database v22.12)',
-	'GNUmed 1.8.1 Release Notes:
+	'Release Notes for GNUmed 1.8.3 (database v22.13)',
+	'GNUmed 1.8.3 Release Notes:
 
-	1.8.1
+	1.8.3
 
-NEW: tool: read_all_rows_of_table
+NEW: tool: fingerprint_db
 
-FIX: bills: failure to generate bill PDFs [thanks Marc]
-FIX: bills: failure to edit bill item date [thanks Marc]
-FIX: bills: failure to edit billable [thanks Marc]
-FIX: export area: fails to load when gm-burn.sh not found [thanks Marc]
-FIX: demographics: failure to edit type of address [thanks Marc]
-FIX: forms: failure to archive generated forms [thanks Marc]
-FIX: demographics: faulty display of patient addresses [thanks Marc]
+IMPROVED: forms: log pdflatex version
 
-	22.12
+FIX: meds: drug data source selection [thanks bganglia892]
+FIX: meds: ADR URL configuration [thanks bganglia892]
+FIX: vaccs: ADR URL configuration [thanks bganglia892]
+FIX: tests: LOINC import fixup [thanks bganglia892]
+FIX: db: whitespace in connection parameters [thanks kikiruz]
+FIX: startup: startup without console fails [thanks Marc]
+FIX: top panel: incorrect age-at-birthday display
+FIX: i18n: locale activation
 
-IMPROVED: robustify backup script
+	22.13
+
+IMPROVED: bootstrapper logging
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.12');
+select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.13@1.8.3');
